Attribute VB_Name = "FunctionsAndGlobals"

Public Function eqvStress(sx As Double, sy As Double, sz As Double, sxy As Double, syz As Double, szx As Double) As Double
Dim s1 As Double, s2 As Double, s3 As Double
Dim sInt1 As Double, sInt2 As Double, sInt3 As Double

Call principalStress(sx, sy, sz, sxy, syz, szx, s1, s2, s3)

If Form1.crit1.Value = True Then  ' Von Mises criteria
    eqvStress = Sqr(0.5 * ((s1 - s2) ^ 2 + (s2 - s3) ^ 2 + (s3 - s1) ^ 2))
End If

If Form1.crit2.Value = True Then  ' Tresca's criteria
    sInt1 = Abs(s1 - s2)
    sInt2 = Abs(s2 - s3)
    sInt3 = Abs(s3 - s1)
    If sInt1 > sInt2 Then
        If sInt1 > sInt3 Then
            eqvStress = sInt1
        Else
            eqvStress = sInt3
        End If
    Else
        If sInt2 > sInt3 Then
            eqvStress = sInt2
        Else
            eqvStress = sInt3
        End If
    End If
End If

End Function


Public Function principalStress(sx As Double, sy As Double, sz As Double, sxy As Double, syz As Double, szx As Double, s1 As Double, s2 As Double, s3 As Double)
' Determine the principal stresses from the stress components
Dim pi As Double
Dim j1 As Double, j2 As Double, j3 As Double  ' Stress invariants
Dim g As Double, h As Double, cos3theta As Double, theta As Double
pi = 3.14159265358979

j1 = sx + sy + sz
j2 = (sx * sy + sy * sz + sz * sx) - (sxy * sxy + syz * syz + szx * szx)
j3 = sx * sy * sz + 2 * sxy * syz * szx - (sx * syz * syz + sy * szx * szx + sz * sxy * sxy)

g = (j1 * j2 / 3) - (2 * j1 * j1 * j1 / 27) - j3
h = -j2 + (j1 * j1 / 3)

If g = 0 Or h = 0 Then
    cos3theta = 0
Else
    cos3theta = (g / 2) * ((h / 3) ^ (-1.5))
End If

If Abs(CSng(cos3theta)) = 1 Then
    theta = 0
Else
    If cos3theta = 0 Then
        theta = pi / 2
    Else
        theta = Atn(Sqr(1 / (cos3theta * cos3theta) - 1))
    End If
End If

s1 = (j1 / 3) + 2 * Sqr(h / 3) * Cos(theta)
s2 = (j1 / 3) + 2 * Sqr(h / 3) * Cos(theta + 2 * pi / 3)
s3 = (j1 / 3) + 2 * Sqr(h / 3) * Cos(theta + 4 * pi / 3)

End Function


Public Function findIntersection(v1low As Double, v1high As Double, v2low As Double, v2high As Double, vLow As Double, vHigh As Double) As Boolean
' Finds intersection of two ranges defined by (v1low, v1high) and (v2low, v2high)
' returns 'True' if intersection found, else returns 'False'

If v1low > v2low Then
    vLow = v1low
Else
    vLow = v2low
End If

If v1high < v2high Then
    vHigh = v1high
Else
    vHigh = v2high
End If

If vLow <= vHigh Then
    findIntersection = True
Else
    findIntersection = False
End If

End Function
